Paragraph class

A paragraph, with Bangla shaped correctly.

Mirrors pw.Paragraph, with the text positional. The alignment default is pw.TextAlign.start rather than justify, which is what this package has always done.

Inheritance

Constructors

Paragraph(String text, {double fontSize = 14, FontWeight fontWeight = pw.FontWeight.normal, TextAlign textAlign = pw.TextAlign.start, EdgeInsetsGeometry margin = const pw.EdgeInsets.only(bottom: 12), EdgeInsetsGeometry? padding, Font? banglaFont, TextStyle? style, TextStyle? banglaStyle})
Creates a Paragraph.

Properties

banglaFont Font?
The font to use for Bangla runs.
final
banglaStyle TextStyle?
Style for Bangla runs.
final
box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
canSpan bool
no setterinherited
fontSize double
Font size.
final
fontWeight FontWeight
Font weight.
final
hashCode int
The hash code for this object.
no setterinherited
hasMoreWidgets bool
no setterinherited
margin EdgeInsetsGeometry
Space outside the paragraph.
final
padding EdgeInsetsGeometry?
Space inside the paragraph.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
Style for non-Bangla runs.
final
text String
The paragraph text.
final
textAlign TextAlign
Horizontal alignment.
final

Methods

applyContext(covariant WidgetContext context) → void
Called before relayout to restore the saved state and restart the layout in the same conditions
inherited
build(Context context) Widget
override
cloneContext() WidgetContext
Called after layout to save the state
inherited
debugPaint(Context context) → void
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
inherited
restoreContext(covariant WidgetContext context) → void
Apply the context for next page layout. Called before layout to prepare for next page
inherited
saveContext() WidgetContext
Get unmodified mutable context object
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited