Bullet class

One bulleted item, with Bangla shaped correctly.

Mirrors pw.Bullet.

Inheritance

Constructors

Bullet({String? text, TextAlign textAlign = pw.TextAlign.left, TextStyle? style, EdgeInsetsGeometry margin = const pw.EdgeInsets.only(bottom: 2.0 * PdfPageFormat.mm), EdgeInsetsGeometry? padding, double bulletSize = 2.0 * PdfPageFormat.mm, EdgeInsetsGeometry bulletMargin = const pw.EdgeInsets.only(top: 1.5 * PdfPageFormat.mm, left: 5.0 * PdfPageFormat.mm, right: 2.0 * PdfPageFormat.mm), BoxShape bulletShape = pw.BoxShape.circle, PdfColor bulletColor = PdfColors.black})
Creates a Bullet.

Properties

box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
bulletColor → PdfColor
Colour of the bullet marker.
final
bulletMargin EdgeInsetsGeometry
Space around the bullet marker.
final
bulletShape BoxShape
Shape of the bullet marker.
final
bulletSize double
Diameter of the bullet marker.
final
canSpan bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasMoreWidgets bool
no setterinherited
margin EdgeInsetsGeometry
Space outside the item.
final
padding EdgeInsetsGeometry?
Space inside the item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
Style for the text.
final
text String?
The item's text.
final
textAlign TextAlign
Horizontal alignment.
final

Methods

applyContext(covariant WidgetContext context) → void
Called before relayout to restore the saved state and restart the layout in the same conditions
inherited
build(Context context) Widget
override
cloneContext() WidgetContext
Called after layout to save the state
inherited
debugPaint(Context context) → void
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
inherited
restoreContext(covariant WidgetContext context) → void
Apply the context for next page layout. Called before layout to prepare for next page
inherited
saveContext() WidgetContext
Get unmodified mutable context object
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited