source property
PdfPoint?
source
final
The size of the part of the input to show on the output.
Implementation
final PdfPoint? source;
The size of the part of the input to show on the output.
final PdfPoint? source;