FractionalOffset class

An offset that's expressed as a fraction of a PdfPoint.

Inheritance
Annotations

Constructors

FractionalOffset(double dx, double dy)
Creates a fractional offset.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
The distance fraction in the horizontal direction.
finalinherited
y double
The distance fraction in the vertical direction.
finalinherited

Methods

alongSize(PdfPoint other) → PdfPoint
Returns the offset that is this fraction within the given size.
inherited
inscribe(PdfPoint size, PdfRect rect) → PdfRect
Returns a rect of the given size, aligned within given rect as specified by this alignment.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(TextDirection? direction) Alignment
Convert this instance into an Alignment, which uses literal coordinates (the x coordinate being explicitly a distance from the left).
inherited
toString() String
A string representation of this object.
inherited
withinRect(PdfRect rect) → PdfPoint
Returns the point that is this fraction within the given rect.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited