GridAxis class abstract

Inheritance
Implementers

Constructors

GridAxis({GridAxisFormat? format, TextStyle? textStyle, double? margin, double? marginStart, double? marginEnd, PdfColor? color, double? width, bool? divisions, double? divisionsWidth, PdfColor? divisionsColor, bool? divisionsDashed, bool? ticks, bool? axisTick, double angle = 0, GridAxisBuildLabel? buildLabel})

Properties

angle double
final
axisPosition double
getter/setter pair
box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
buildLabel GridAxisBuildLabel?
final
color → PdfColor
final
crossAxisPosition double
getter/setter pair
direction Axis
getter/setter pair
divisions bool
final
divisionsColor → PdfColor
final
divisionsDashed bool
final
divisionsWidth double
final
format GridAxisFormat
final
hashCode int
The hash code for this object.
no setterinherited
margin double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
final
ticks bool
final
width double
final

Methods

debugPaint(Context context) → void
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
inherited
paintBackground(Context context) → void
toChart(num? input) double
toString() String
A string representation of this object.
inherited
transfer(num input) double

Operators

operator ==(Object other) bool
The equality operator.
inherited