horizontalColor property
PdfColor
horizontalColor
final
The color to draw the horizontal lines in the grid.
Implementation
final PdfColor horizontalColor;
The color to draw the horizontal lines in the grid.
final PdfColor horizontalColor;