verticalColor property
PdfColor
verticalColor
final
The color to draw the vertical lines in the grid.
Implementation
final PdfColor verticalColor;
The color to draw the vertical lines in the grid.
final PdfColor verticalColor;