Header class

A section heading, with Bangla shaped correctly.

Mirrors pw.Header, including the PDF outline entry it adds.

Inheritance

Constructors

Header({int level = 1, String? text, Widget? child, BoxDecoration? decoration, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, TextStyle? textStyle, String? title, PdfColor? outlineColor, PdfOutlineStyle outlineStyle = PdfOutlineStyle.normal})
Creates a Header.

Properties

box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
canSpan bool
no setterinherited
child Widget?
A widget to use instead of text.
final
decoration BoxDecoration?
Background and border.
final
hashCode int
The hash code for this object.
no setterinherited
hasMoreWidgets bool
no setterinherited
level int
Heading level, 0 to 5.
final
margin EdgeInsetsGeometry?
Space outside the heading.
final
outlineColor → PdfColor?
Colour of the PDF outline entry.
final
outlineStyle → PdfOutlineStyle
Style of the PDF outline entry.
final
padding EdgeInsetsGeometry?
Space inside the heading.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The heading text. Ignored when child is given.
final
textStyle TextStyle?
Style for the heading text.
final
title String?
The outline entry's title. Defaults to text.
final

Methods

applyContext(covariant WidgetContext context) → void
Called before relayout to restore the saved state and restart the layout in the same conditions
inherited
build(Context context) Widget
override
cloneContext() WidgetContext
Called after layout to save the state
inherited
debugPaint(Context context) → void
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
inherited
restoreContext(covariant WidgetContext context) → void
Apply the context for next page layout. Called before layout to prepare for next page
inherited
saveContext() WidgetContext
Get unmodified mutable context object
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited