ImageImage class

Inheritance

Constructors

ImageImage(Image _image, {double? dpi, PdfImageOrientation? orientation})

Properties

dpi double?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height int?
Image height
no setterinherited
orientation → PdfImageOrientation
The internal orientation of the image
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
Image width
no setterinherited

Methods

buildImage(Context context, {int? width, int? height}) → PdfImage
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Context context, PdfPoint size, {double? dpi}) → PdfImage
Resolves this image provider using the given context, returning a PdfImage The image is automatically added to the document
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited