ImageProvider class abstract

Identifies an image without committing to the precise final asset

Constructors

ImageProvider(int? _width, int _height, PdfImageOrientation orientation, double? dpi)

Properties

dpi double?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
Image height
no setter
orientation → PdfImageOrientation
The internal orientation of the image
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
Image width
no setter

Methods

buildImage(Context context, {int? width, int? height}) → PdfImage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Context context, PdfPoint size, {double? dpi}) → PdfImage
Resolves this image provider using the given context, returning a PdfImage The image is automatically added to the document
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited