Page class

Constructors

Page({PageTheme? pageTheme, PdfPageFormat? pageFormat, required BuildCallback build, ThemeData? theme, PageOrientation? orientation, EdgeInsetsGeometry? margin, bool clip = false, TextDirection? textDirection})

Properties

hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsetsGeometry?
no setter
mustRotate bool
no setter
orientation PageOrientation
no setter
pageFormat → PdfPageFormat
no setter
pageTheme PageTheme
final
resolvedMargin EdgeInsets?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme ThemeData?
no setter

Methods

debugPaint(Context context) → void
generate(Document document, {bool insert = true, int? index}) → void
layout(Widget child, Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → PdfPoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Widget child, Context context) → void
postProcess(Document document) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited