PieDataSet class

Inheritance

Constructors

PieDataSet({required num value, String? legend, required PdfColor color, PdfColor? borderColor = PdfColors.white, double borderWidth = 1.5, bool? drawBorder, bool drawSurface = true, double surfaceOpacity = 1, double offset = 0, TextStyle? legendStyle, TextAlign? legendAlign, PieLegendPosition legendPosition = PieLegendPosition.auto, double legendLineWidth = 1.0, PdfColor? legendLineColor, Widget? legendWidget, double legendOffset = 20, double innerRadius = 0})

Properties

angleEnd double
getter/setter pair
angleStart double
getter/setter pair
borderColor → PdfColor?
finalinherited
borderWidth double
finalinherited
box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
color → PdfColor?
finalinherited
drawBorder bool
final
drawSurface bool
final
hashCode int
The hash code for this object.
no setterinherited
innerRadius double
final
legend String?
finalinherited
legendAlign TextAlign?
final
legendLineColor → PdfColor
final
legendLineWidth double
final
legendOffset double
final
legendPosition PieLegendPosition
final
legendStyle TextStyle?
final
offset double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surfaceOpacity double
final
value num
final

Methods

debugPaint(Context context) → void
override
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
override
legendShape(Context context) Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
override
paintBackground(Context context) → void
override
paintForeground(Context context) → void
inherited
paintLegend(Context context) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited