Signature class

Inheritance
Mixed-in types

Constructors

Signature({Widget? child, @Deprecated('Use value instead') PdfSignatureBase? crypto, PdfSignatureBase? value, required String name, bool appendOnly = false, PdfBorder? border, Set<PdfAnnotFlags>? flags, DateTime? date, PdfColor? color, PdfAnnotHighlighting? highlighting, List<Uint8List>? crl, List<Uint8List>? cert, List<Uint8List>? ocsp, PdfIndirect? replaces})

Properties

appendOnly bool
Append
final
border → PdfBorder?
final
box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
canSpan bool
no setterinherited
cert List<Uint8List>?
Additional X509 certificates
final
child Widget?
finalinherited
color → PdfColor?
Field color
final
crl List<Uint8List>?
Certificate revocation lists
final
date DateTime?
Date metadata
final
flags Set<PdfAnnotFlags>?
Flags for this field
final
hashCode int
The hash code for this object.
no setterinherited
hasMoreWidgets bool
no setterinherited
highlighting → PdfAnnotHighlighting?
Field highlighting
final
name String
Field name
final
ocsp List<Uint8List>?
Online Certificate Status Protocol
final
replaces → PdfIndirect?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → PdfSignatureBase?
Digital signature
final

Methods

applyContext(covariant WidgetContext context) → void
Called before relayout to restore the saved state and restart the layout in the same conditions
inherited
cloneContext() WidgetContext
Called after layout to save the state
inherited
debugPaint(Context context) → void
inherited
drawAppearance(Context context, PdfAnnotBase bf, Matrix4 mat, Widget child, {PdfAnnotAppearance type = PdfAnnotAppearance.normal, PdfName? tag, String? name, bool selected = false}) → void
inherited
getAppearanceMatrix(Context context) Matrix4
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
override
paintChild(Context context) → void
inherited
restoreContext(covariant WidgetContext context) → void
Apply the context for next page layout. Called before layout to prepare for next page
inherited
saveContext() WidgetContext
Get unmodified mutable context object
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited