TableOfContent class
A table of contents built from the document outline, with Bangla shaped correctly.
Mirrors pw.TableOfContent. Outline titles come from Header, so they are
exactly as likely to be Bangla as any other heading.
- Inheritance
-
- Object
- Widget
- StatelessWidget
- TableOfContent
Constructors
- TableOfContent()
- Creates a TableOfContent.
Properties
- box ↔ PdfRect?
-
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
- canSpan → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMoreWidgets → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyContext(
covariant WidgetContext context) → void -
Called before relayout to restore the saved state and
restart the layout in the same conditions
inherited
-
build(
Context context) → Widget -
override
-
cloneContext(
) → WidgetContext -
Called after layout to save the state
inherited
-
debugPaint(
Context context) → void -
inherited
-
layout(
Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void -
First widget pass to calculate the children layout and
bounding box
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Context context) → void -
Draw itself and its children, according to the calculated
box.offsetinherited -
restoreContext(
covariant WidgetContext context) → void -
Apply the context for next page layout.
Called before layout to prepare for next page
inherited
-
saveContext(
) → WidgetContext -
Get unmodified mutable context object
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited