TextSpan class

A span of styled text, with Bangla shaped correctly.

Extends pw.TextSpan, so it is a real pw.InlineSpan and can be nested with pw.WidgetSpan or passed to any package:pdf widget that takes one.

Inheritance

Constructors

TextSpan({TextStyle? style, String? text, double baseline = 0, List<InlineSpan>? children, AnnotationBuilder? annotation})
Creates a TextSpan.
const

Properties

annotation AnnotationBuilder?
finalinherited
baseline double
finalinherited
children List<InlineSpan>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
finalinherited
text String?
finalinherited

Methods

copyWith({TextStyle? style, double? baseline, AnnotationBuilder? annotation}) InlineSpan
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPlainText() String
inherited
toString() String
A string representation of this object.
inherited
visitChildren(VisitorCallback visitor, TextStyle? parentStyle, AnnotationBuilder? annotation) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited