Transform class

Inheritance

Constructors

Transform({required Matrix4 transform, PdfPoint? origin, AlignmentGeometry? alignment, bool adjustLayout = false, bool unconstrained = false, Widget? child})
Transform.rotate({required double angle, PdfPoint? origin, AlignmentGeometry? alignment = Alignment.center, Widget? child})
Creates a widget that transforms its child using a rotation around the center.
Transform.rotateBox({required double angle, Widget? child, bool unconstrained = false})
Creates a widget that transforms its child using a rotation around the center and relayout the bounding box.
Transform.scale({required double scale, PdfPoint? origin, AlignmentGeometry? alignment = Alignment.center, Widget? child})
Creates a widget that scales its child uniformly.
Transform.translate({required PdfPoint offset, Widget? child})
Creates a widget that transforms its child using a translation.

Properties

adjustLayout bool
final
alignment AlignmentGeometry?
The alignment of the origin, relative to the size of the box.
final
box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
canSpan bool
no setterinherited
child Widget?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasMoreWidgets bool
no setterinherited
origin → PdfPoint?
The origin of the coordinate system
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform Matrix4
The matrix to transform the child by during painting.
final
unconstrained bool
final

Methods

applyContext(covariant WidgetContext context) → void
Called before relayout to restore the saved state and restart the layout in the same conditions
inherited
cloneContext() WidgetContext
Called after layout to save the state
inherited
debugPaint(Context context) → void
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
override
paintChild(Context context) → void
inherited
restoreContext(covariant WidgetContext context) → void
Apply the context for next page layout. Called before layout to prepare for next page
inherited
saveContext() WidgetContext
Get unmodified mutable context object
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited