Widget class abstract
Constructors
- Widget()
Properties
- box ↔ PdfRect?
-
The bounding box of this widget, calculated at layout time
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debugPaint(
Context context) → void -
layout(
Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void - First widget pass to calculate the children layout and bounding box
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Context context) → void -
Draw itself and its children, according to the calculated
box.offset -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
draw(
Widget widget, {PdfPage? page, PdfGraphics? canvas, BoxConstraints? constraints, required PdfPoint offset, AlignmentGeometry? alignment, Context? context}) → void - Draw a widget to a page canvas.
-
measure(
Widget widget, {PdfPage? page, PdfGraphics? canvas, BoxConstraints? constraints, Context? context}) → PdfPoint - Measure the size of a widget to a page canvas.