ExtractedPage class
One extracted page.
Constructors
- ExtractedPage({required int number, required String text, required BanglaTextEncoding encodingDetected, required bool hasImages})
-
const
Properties
- encodingDetected → BanglaTextEncoding
-
How this page's Bangla was encoded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasImages → bool
-
Whether the page draws any image.
final
- number → int
-
1-based page number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The page's text, in reading order.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited