isLocked property
Whether the document is encrypted and could not be opened.
True when a password is genuinely required, or the document uses a security handler this does not implement. The text will be empty.
Implementation
final bool isLocked;
Whether the document is encrypted and could not be opened.
True when a password is genuinely required, or the document uses a security handler this does not implement. The text will be empty.
final bool isLocked;