TableHelper mixin

Builds a pw.Table from raw data, with Bangla shaped correctly.

Mirrors pw.TableHelper.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromTextArray({Context? context, required List<List> data, EdgeInsetsGeometry cellPadding = const pw.EdgeInsets.all(5), double cellHeight = 0, AlignmentGeometry cellAlignment = pw.Alignment.topLeft, Map<int, AlignmentGeometry>? cellAlignments, TextStyle? cellStyle, TextStyle? oddCellStyle, OnCellFormat? cellFormat, OnCellDecoration? cellDecoration, int headerCount = 1, List? headers, EdgeInsetsGeometry? headerPadding, double? headerHeight, AlignmentGeometry headerAlignment = pw.Alignment.center, Map<int, AlignmentGeometry>? headerAlignments, TextStyle? headerStyle, OnCellFormat? headerFormat, TableBorder? border = const pw.TableBorder(left: pw.BorderSide(), right: pw.BorderSide(), top: pw.BorderSide(), bottom: pw.BorderSide(), horizontalInside: pw.BorderSide(), verticalInside: pw.BorderSide()), Map<int, TableColumnWidth>? columnWidths, TableColumnWidth defaultColumnWidth = const pw.IntrinsicColumnWidth(), TableWidth tableWidth = pw.TableWidth.max, BoxDecoration? headerDecoration, BoxDecoration? headerCellDecoration, BoxDecoration? rowDecoration, BoxDecoration? oddRowDecoration, TextDirection? headerDirection, TextDirection? tableDirection, OnCell? cellBuilder, OnCellTextStyle? textStyleBuilder}) Table
Builds a table from data, mirroring pw.TableHelper.fromTextArray.